==> xl-repository-jcr-9.7.2-718.0838-sources.jar: com/xebialabs/xlplatform/repository/JcrRepositoryMetadataService.scala <==
package com.xebialabs.xlplatform.repository

import javax.jcr.{Node, Property, Session}

import com.xebialabs.deployit.jcr.{JcrCallback, JcrConstants, JcrTemplate}
import com.xebialabs.deployit.repository.RepositoryMetadataService
import com.xebialabs.license.LicenseRepositoryIdException
import grizzled.slf4j.Logging
import org.springframework.beans.factory.annotation.Autowired

class JcrRepositoryMetadataService @Autowired()(jcrTemplate: JcrTemplate) extends RepositoryMetadataService with Logging {

  // Lazy initialised to prevent frequent querying
  protected var storedRepoId: Option[String] = None

  /**
    * Writes the repositoryId. This is a write once value.
    *
    * @param repositoryId unique id for this repository
    * @throws LicenseRepositoryIdException if the repository has already an id
    */

  override def validateAndStoreRepositoryId(repositoryId: String): Unit = {
    (Option(repositoryId), getRepositoryId) match {
      case (Some(newRepoId), Some(current)) => if (current != newRepoId) throw new LicenseRepositoryIdException(repositoryId)
      case (Some(newRepoId), None) => saveRepositoryId(repositoryId)
      case _ => // Don't store
    }
  }

  def saveRepositoryId(repositoryId: String): Unit =
    jcrTemplate.execute(new JcrCallback[String]() {
      def doInJcr(session: Session): String = {
        val configurationNode: Node = session.getNode(JcrConstants.CONFIGURATION_NODE_ID)
        val property: Property = configurationNode.setProperty(JcrConstants.REPOSITORY_ID_PROPERTY_NAME, repositoryId)
        session.save()
        property.getString
      }
    })

  def getRepositoryId: Option[String] = {
    storedRepoId match {
      case Some(_) =>
      case None => storedRepoId = queryRepositoryId
    }
    storedRepoId
  }

  def queryRepositoryId: Option[String] = {
    jcrTemplate.execute(new JcrCallback[Option[String]]() {
      def doInJcr(session: Session): Option[String] = {
        val configurationNode = session.getNode(JcrConstants.CONFIGURATION_NODE_ID)
        if (configurationNode.hasProperty(JcrConstants.REPOSITORY_ID_PROPERTY_NAME)) {
          Some(configurationNode.getProperty(JcrConstants.REPOSITORY_ID_PROPERTY_NAME).getString)
        }
        else {
          None
        }
      }
    })
  }
}

==> xl-repository-jcr-2015.6.4-sources.jar: com/xebialabs/xlplatform/repository/JcrRepositoryMetadataService.scala <==
package com.xebialabs.xlplatform.repository

import javax.jcr.{Node, Property, Session}

import com.google.common.base.{Preconditions, Strings}
import com.xebialabs.deployit.jcr.{JcrCallback, JcrConstants, JcrTemplate}
import com.xebialabs.deployit.repository.RepositoryMetadataService
import com.xebialabs.license.LicenseRepositoryIdException
import grizzled.slf4j.Logging

class JcrRepositoryMetadataService(jcrTemplate: JcrTemplate) extends RepositoryMetadataService with Logging {

  // Lazy initialised to prevent frequent querying
  private var storedRepoId: Option[String] = None

  /**
   * Writes the repositoryId. This is a write once value.
   * @param repositoryId unique id for this repository
   * @throws LicenseRepositoryIdException if the repository has already an id
   */

  override def validateAndStoreRepositoryId(repositoryId: String): Unit = {
    Preconditions.checkArgument(!Strings.isNullOrEmpty(repositoryId))
    getRepositoryId match {
      case Some(current) => if (current != repositoryId) throw new LicenseRepositoryIdException(current, repositoryId)
      case None => saveRepositoryId(repositoryId)
    }
  }

  def saveRepositoryId(repositoryId: String): Unit =
    jcrTemplate.execute(new JcrCallback[String]() {
      def doInJcr(session: Session): String = {
        val configurationNode: Node = session.getNode(JcrConstants.CONFIGURATION_NODE_ID)
        val property: Property = configurationNode.setProperty(JcrConstants.REPOSITORY_ID_PROPERTY_NAME, repositoryId)
        session.save()
        property.getString
      }
    })

  private def getRepositoryId: Option[String] = {
    storedRepoId match {
      case Some(_) =>
      case None => storedRepoId = queryRepositoryId
    }
    storedRepoId
  }

  private def queryRepositoryId: Option[String] = {
    jcrTemplate.execute(new JcrCallback[Option[String]]() {
      def doInJcr(session: Session): Option[String] = {
        val configurationNode = session.getNode(JcrConstants.CONFIGURATION_NODE_ID)
        if (configurationNode.hasProperty(JcrConstants.REPOSITORY_ID_PROPERTY_NAME)) {
          Some(configurationNode.getProperty(JcrConstants.REPOSITORY_ID_PROPERTY_NAME).getString)
        }
        else {
          None
        }
      }
    })
  }
}
